# Authors

* Hobson Lane <hobson@tangibleai.com>
* Maria Dyshel <maria@tangibleai.com>
* Leo Hepis <leo@leohepis.com>
* Geoffrey Marshal
* Sylvia Lee
* Winnie Yeung @dcvionwinnie
* Mohammed Dala Ali <mms.dala@gmail.com>
* Travis Harper @travis-harper
* Copeland Royall
* Alex Rosengarten @alxrsngrtn
* Jose Robins @jorobins

